#!/usr/bin/perl -w
use strict;

exec 'psh -r pshrc';

